@@ -17,7 +17,7 @@
 #'
 #'}
 commons_terms <- function(search = NULL, class = NULL, extra_args = NULL, tidy = TRUE, tidy_style = "snake_case") {
-    
+
     if (is.null(search) == FALSE) {
         search <- utils::URLencode(search)
         search_query <- paste0("&_search=", search)
@@ -27,7 +27,8 @@ commons_terms <- function(search = NULL, class = NULL, extra_args = NULL, tidy =
     if (is.null(class) == FALSE) {
         class_list <- list("ID", "ORG", "SIT", "NAME", "LEG", "CTP", "PBT", "TPG")
         if (!(class %in% class_list)) {
-            stop("Please check your class parameter. It must be one of \"ID\", \"ORG\", \"SIT\", \"NAME\", \"LEG\", \"CTP\", \"PBT\" or\"TPG\"", call. = FALSE)
+            stop("Please check your class parameter. It must be one of \"ID\", \"ORG\", \"SIT\", \"NAME\", \"LEG\", \"CTP\", \"PBT\" or\"TPG\"",
+                call. = FALSE)
         } else {
             class_query <- paste0("&class=", class)
         }
@@ -37,30 +38,44 @@ commons_terms <- function(search = NULL, class = NULL, extra_args = NULL, tidy =
     baseurl <- "http://lda.data.parliament.uk/terms.json?_pageSize=500&_view=description"
     message("Connecting to API")
     terms <- jsonlite::fromJSON(paste0(baseurl, search_query, class_query, extra_args), flatten = TRUE)
-    jpage <- round(terms$result$totalResults/terms$result$itemsPerPage, digits = 0)
+    jpage <- floor(terms$result$totalResults/terms$result$itemsPerPage)
     pages <- list()
     for (i in 0:jpage) {
         mydata <- jsonlite::fromJSON(paste0(baseurl, search_query, class_query, "&_page=", i, extra_args), flatten = TRUE)
         message("Retrieving page ", i + 1, " of ", jpage + 1)
         pages[[i + 1]] <- mydata$result$items
     }
-    
+
     df <- tibble::as_tibble(dplyr::bind_rows(pages))
-    
+
     if (nrow(df) == 0) {
         message("The request did not return any data. Please check your search parameters.")
     } else {
-        
+
         if (tidy == TRUE) {
-            
+
             df <- hansard::hansard_tidy(df, tidy_style)
-            
+
             df
-            
+
         } else {
-            
+
             df
-            
+
         }
     }
 }
+
+
+#' @rdname commons_terms
+#' @export
+hansard_commons_terms <- function(search = NULL, class = NULL, extra_args = NULL, tidy = TRUE, tidy_style = "snake_case") {
+
+  df <- commons_terms(search = search, class = class, extra_args = extra_args, tidy = tidy, tidy_style = tidy_style)
+
+  df
+
+}
+
+
+
