@@ -17,71 +17,90 @@
 #'
 #' }
 
-commons_written_questions <- function(mp_id = NULL, answering_department = NULL, start_date = "1900-01-01", end_date = Sys.Date(), extra_args = NULL, tidy = TRUE, tidy_style = "snake_case") {
-    
+commons_written_questions <- function(mp_id = NULL, answering_department = NULL, start_date = "1900-01-01", end_date = Sys.Date(),  extra_args = NULL, tidy = TRUE, tidy_style = "snake_case") {
+
     dates <- paste0("&_properties=dateTabled&max-dateTabled=", as.Date(end_date), "&min-dateTabled=", as.Date(start_date))
-    
+
     if (is.null(mp_id) == FALSE) {
         mp_id <- paste0("&tablingMember=http://data.parliament.uk/members/", mp_id)
-        
+
         mp_id <- utils::URLencode(mp_id)
     }
-    
+
     if (is.null(answering_department) == FALSE) {
-        
+
         query <- "/answeringdepartment"
-        
+
         answering_department <- paste0("q=", answering_department)
-        
+
         answering_department <- utils::URLencode(answering_department)
-        
+
     } else {
-        
+
         query <- NULL
-        
+
     }
-    
+
     baseurl <- "http://lda.data.parliament.uk/commonswrittenquestions"
-    
+
     message("Connecting to API")
-    
-    writ <- jsonlite::fromJSON(paste0(baseurl, query, ".json?", answering_department, mp_id, dates, "&_pageSize=500", extra_args), flatten = TRUE)
-    
-    jpage <- round(writ$result$totalResults/writ$result$itemsPerPage, digits = 0)
-    
+
+    writ <- jsonlite::fromJSON(paste0(baseurl, query, ".json?", answering_department, mp_id, dates, "&_pageSize=500", extra_args),
+        flatten = TRUE)
+
+    jpage <- floor(writ$result$totalResults/writ$result$itemsPerPage)
+
     pages <- list()
-    
+
     for (i in 0:jpage) {
-        mydata <- jsonlite::fromJSON(paste0(baseurl, query, ".json?", answering_department, mp_id, dates, "&_pageSize=500&_page=", i, extra_args), flatten = TRUE)
+        mydata <- jsonlite::fromJSON(paste0(baseurl, query, ".json?", answering_department, mp_id, dates, "&_pageSize=500&_page=",
+            i, extra_args), flatten = TRUE)
         message("Retrieving page ", i + 1, " of ", jpage + 1)
         pages[[i + 1]] <- mydata$result$items
     }
-    
+
     df <- tibble::as_tibble(dplyr::bind_rows(pages))
-    
+
     if (nrow(df) == 0) {
         message("The request did not return any data. Please check your search parameters.")
     } else {
-        
+
         if (tidy == TRUE) {
-            
+
             df$AnswerDate._value <- as.POSIXct(df$AnswerDate._value)
-            
+
             df$dateTabled._value <- as.POSIXct(df$dateTabled._value)
-            
+
             df$dateTabled._datatype <- "POSIXct"
-            
+
             df$AnswerDate._datatype <- "POSIXct"
-            
+
+            df$tablingMemberPrinted <- unlist(df$tablingMemberPrinted)
+
+            df$AnsweringBody <- unlist(df$AnsweringBody)
+
+            df$tablingMember._about <- gsub("http://data.parliament.uk/members/", "", df$tablingMember._about)
+
             df <- hansard::hansard_tidy(df, tidy_style)
-            
+
             df
-            
+
         } else {
-            
+
             df
-            
+
         }
-        
+
     }
 }
+
+
+#' @rdname commons_written_questions
+#' @export
+hansard_commons_written_questions <- function(mp_id = NULL, answering_department = NULL, start_date = "1900-01-01", end_date = Sys.Date(),  extra_args = NULL, tidy = TRUE, tidy_style = "snake_case") {
+
+    df <- commons_written_questions(mp_id = mp_id, answering_department = answering_department, start_date = start_date, end_date = end_date, extra_args = extra_args, tidy = tidy, tidy_style = tidy_style)
+
+    df
+
+}
