@@ -17,14 +17,14 @@
 #' x <- publication_logs(683267)
 #' }
 
-publication_logs <- function(ID = NULL, house = NULL, start_date = "1900-01-01", end_date = Sys.Date(), extra_args = NULL, tidy = TRUE, tidy_style = "snake_case") {
-    
+publication_logs <- function(ID = NULL, house = NULL, start_date = "1900-01-01", end_date = Sys.Date(), extra_args = NULL, tidy = TRUE,  tidy_style = "snake_case") {
+
     if (is.null(ID) == FALSE) {
         query <- paste0("/", ID, ".json?")
     } else {
         query <- ".json?&_pageSize=500"
     }
-    
+
     if (is.null(house) == FALSE) {
         house <- tolower(house)
         if (house == "commons") {
@@ -39,54 +39,65 @@ publication_logs <- function(ID = NULL, house = NULL, start_date = "1900-01-01",
     } else {
         house_query <- NULL
     }
-    
+
     dates <- paste0("&_properties=publicationDate&max-publicationDate=", as.Date(end_date), "&min-publicationDate=", as.Date(start_date))
-    
+
     baseurl <- "http://lda.data.parliament.uk/publicationlogs"
-    
+
     message("Connecting to API")
-    
+
     logs <- jsonlite::fromJSON(paste0(baseurl, query, house_query, dates, extra_args), flatten = TRUE)
-    
+
     if (is.null(ID) == FALSE) {
-        
+
         df <- tibble::as_tibble(as.data.frame(logs$result$primaryTopic))
-        
+
     } else {
-        
-        jpage <- round(logs$result$totalResults/logs$result$itemsPerPage, digits = 0)
-        
+
+        jpage <- floor(logs$result$totalResults/logs$result$itemsPerPage)
+
         pages <- list()
-        
+
         for (i in 0:jpage) {
             mydata <- jsonlite::fromJSON(paste0(baseurl, query, house_query, dates, "&_page=", i, extra_args), flatten = TRUE)
             message("Retrieving page ", i + 1, " of ", jpage + 1)
             pages[[i + 1]] <- mydata$result$items
         }
-        
+
         df <- tibble::as_tibble(dplyr::bind_rows(pages))
-        
+
     }
-    
+
     if (nrow(df) == 0) {
         message("The request did not return any data. Please check your search parameters.")
     } else {
-        
+
         if (tidy == TRUE) {
-            
+
             df$publicationDate._value <- as.POSIXct(df$publicationDate._value)
-            
+
             df$publicationDate._datatype <- "POSIXct"
-            
+
             df <- hansard::hansard_tidy(df, tidy_style)
-            
+
             df
-            
+
         } else {
-            
+
             df
-            
+
         }
-        
+
     }
 }
+
+
+#' @rdname publication_logs
+#' @export
+hansard_publication_logs <- function(ID = NULL, house = NULL, start_date = "1900-01-01", end_date = Sys.Date(), extra_args = NULL, tidy = TRUE,  tidy_style = "snake_case") {
+
+  df <- publication_logs(ID=ID, house=house, start_date = start_date, end_date = end_date, extra_args = extra_args, tidy = tidy, tidy_style = tidy_style)
+
+  df
+
+}
