@@ -33,7 +33,7 @@ sessions_info <- function(days = FALSE, start_date = "1900-01-01", end_date = Sy
 
     session <- jsonlite::fromJSON(paste0(baseurl, query, ".json?_pageSize=500", dates, extra_args))
 
-    jpage <- round(session$result$totalResults/session$result$itemsPerPage, digits = 0)
+    jpage <- floor(session$result$totalResults/session$result$itemsPerPage)
 
     pages <- list()
 
@@ -85,3 +85,14 @@ sessions_info <- function(days = FALSE, start_date = "1900-01-01", end_date = Sy
 
     }
 }
+
+
+#' @rdname sessions_info
+#' @export
+hansard_sessions_info <- function(days = FALSE, start_date = "1900-01-01", end_date = Sys.Date(), extra_args = NULL, tidy = TRUE, tidy_style = "snake_case") {
+
+  df <- sessions_info(days=days, start_date = start_date, end_date = end_date, extra_args = extra_args, tidy = tidy, tidy_style = tidy_style)
+
+  df
+
+}
